@@ -35,4 +35,10 @@ class ListPortalMenusRequest(RpcRequest):
 		return self.get_query_params().get('DataPortalId')
 
 	def set_DataPortalId(self,DataPortalId):
-		self.add_query_param('DataPortalId',DataPortalId)
\ No newline at end of file
+		self.add_query_param('DataPortalId',DataPortalId)
+
+	def get_UserId(self):
+		return self.get_query_params().get('UserId')
+
+	def set_UserId(self,UserId):
+		self.add_query_param('UserId',UserId)
\ No newline at end of file
